@@ -41,13 +41,13 @@ def _issue_request(method, relative_url, **kwargs):
         raise FBConnectionException(e.message)
 
     if r.status_code != requests.codes.ok:
-        raise FBHTTPException(r.text)
+        raise FBHTTPException(r.status_code, r.text)
 
     try:
         data = json.loads(r.text)
     except ValueError as e:
         log.warn("Error decoding JSON: {0}. JSON={1}".format(e.message, r.text))
-        raise FBJSONException(e.message)
+        raise FBJSONException("%s (%s)" % (e.message, r.text))
 
     return data
 
@@ -119,6 +119,21 @@ class FBGraph(object):
            
         There are optional params available, see:
         https://developers.facebook.com/docs/reference/api/batch/
+
+        Returns a list of completely deserialized python data structures for
+        each batch response, of the form:
+            [
+                {
+                    "headers": [{ ... }],
+                    "code": 200,
+                    "body": { ... }
+                },
+                ...
+            ]
+
+        If there was an error in an individual response, the "body" will
+        contain the deserialized Facebook error response.
+        See: https://developers.facebook.com/docs/reference/api/batch/
         """
         data = []
         payload = {
